@@ -61,7 +61,7 @@ class ItemsyncTest : public QObject
       qRegisterMetaType<KJob*>();
 
       // switch all resources offline to reduce interference from them
-      foreach ( Akonadi::AgentInstance agent, Akonadi::AgentManager::self()->instances() )
+      foreach ( Akonadi::AgentInstance agent, Akonadi::AgentManager::self()->instances() ) //krazy:exclude=foreach
         agent.setIsOnline( false );
     }
 
@@ -97,9 +97,10 @@ class ItemsyncTest : public QObject
         Item::List l;
         l << origItems[i];
         syncer->setFullSyncItems( l );
-        if ( i < origItems.count() - 1 )
+        if ( i < origItems.count() - 1 ) {
           QTest::qWait( 10 ); // enter the event loop so itemsync actually can do something
-        QCOMPARE( spy.count(), 0 );
+          QCOMPARE( spy.count(), 0 );
+        }
       }
       QTest::qWait( 1000 ); // let it finish its job
       QCOMPARE( spy.count(), 1 );
